# Configuring the Integration
### On this page
  * [Setup in SAP Signavio](https://help.sap.com/docs/leanix/ea/configuring-integration#setup-in-sap-signavio)
  * [Minimum Access Rights for Integration](https://help.sap.com/docs/leanix/ea/configuring-integration#minimum-access-rights-for-integration)
  * [Setup in SAP LeanIX](https://help.sap.com/docs/leanix/ea/configuring-integration#setup-in-sap-leanix)
  * [Setting Up Authentication](https://help.sap.com/docs/leanix/ea/configuring-integration#setting-up-authentication)
  * [Configuration Name](https://help.sap.com/docs/leanix/ea/configuring-integration#configuration-name)
  * [SAP Signavio URL](https://help.sap.com/docs/leanix/ea/configuring-integration#sap-signavio-url)
  * [Username and Password](https://help.sap.com/docs/leanix/ea/configuring-integration#username-and-password)
  * [Tenant ID](https://help.sap.com/docs/leanix/ea/configuring-integration#tenant-id)


View all
Learn how to configure authentication for the SAP Signavio integration, including the necessary SAP Signavio user permissions required for proper setup and synchronization.
